@@ -1,16 +1,13 @@
 package Hubot::Adapter;
 {
-  $Hubot::Adapter::VERSION = '0.2.4';
+  $Hubot::Adapter::VERSION = '0.2.5';
 }
 use Moose;
 use namespace::autoclean;
 
 extends 'Hubot::EventEmitter';
 
-has 'robot' => (
-    is  => 'ro',
-    isa => 'Hubot::Robot'
-);
+has 'robot' => ( is => 'ro', isa => 'Hubot::Robot' );
 
 sub send    { }
 sub whisper { }
@@ -39,6 +36,10 @@ __PACKAGE__->meta->make_immutable;
 
 Hubot::Adapter - specific interface to a chat source for robots.
 
+=head1 VERSION
+
+version 0.2.5
+
 =head1 SYNOPSIS
 
     use Hubot::Robot;
