@@ -1,6 +1,6 @@
 package Hubot::Adapter::Campfire;
 {
-  $Hubot::Adapter::Campfire::VERSION = '0.2.4';
+  $Hubot::Adapter::Campfire::VERSION = '0.2.5';
 }
 use Moose;
 use namespace::autoclean;
@@ -18,22 +18,13 @@ use Try::Tiny;
 
 use Hubot::Message;
 
-has 'robot' => (
-    is  => 'ro',
-    isa => 'Hubot::Robot',
-);
+has 'robot' => ( is => 'ro', isa => 'Hubot::Robot', );
 
-has 'cv' => (
-    is         => 'ro',
-    lazy_build => 1,
-);
+has 'cv' => ( is => 'ro', lazy_build => 1, );
 
 has 'bot' => ( is => 'rw', );
 
-has 'httpClient' => (
-    is      => 'ro',
-    default => sub { LWP::UserAgent->new },
-);
+has 'httpClient' => ( is => 'ro', default => sub { LWP::UserAgent->new }, );
 
 sub _build_cv { AnyEvent->condvar }
 
@@ -72,8 +63,7 @@ sub run {
         'message',
         sub {
             my ( $e, $data ) = @_;
-            my $user =
-              $self->userForId( $data->{user_id},
+            my $user = $self->userForId( $data->{user_id},
                 { room => $data->{room_id}, } );
 
             if ( $user->{name} eq $user->{id} ) {
@@ -146,6 +136,10 @@ __PACKAGE__->meta->make_immutable;
 
 Hubot::Adapter::Campfire - Campfire adapter for L<Hubot>
 
+=head1 VERSION
+
+version 0.2.5
+
 =head1 SYNOPSIS
 
     $ export HUBOT_CAMPFIRE_TOKEN='xxxx'
